@@ -66,16 +66,13 @@ def notify():
 @cmd.command()
 @click.option('--append-details', is_flag=True, default=False)
 @click.option('--for-real', is_flag=True, default=False)
-@click.option('--from-db', is_flag=True, default=False)
 @click.option('--send-mail', is_flag=True, default=False)
-def apply(append_details, for_real, from_db, send_mail):
+def apply(append_details, for_real, send_mail):
     """Appliquer les politiques de FUP pour tous les clients Business"""
     result = {}
     products = Product.all()
     for product in products:
-        policies = product.apply_policies(
-            for_real=for_real
-            )
+        policies = product.apply_policies(for_real=for_real)
         if policies:
             result[product.name] = policies
     if result:
