@@ -6,6 +6,7 @@ from itertools import groupby, repeat
 from .consts import CONFIG
 from .consts import FUPDB_CREDENTIALS
 from .consts import LOGS
+from .consts import REDIS_DB
 from .consts import REST_CLIENT
 from . import core
 from . import product
@@ -82,7 +83,7 @@ class Customer(object):
             with records.Database(url) as db:
                 sql = "DELETE FROM customer WHERE name=:name"
                 db.query(sql, name=self.name)
-                sql = "DELETE FROM cdr WHERE name=:name"
+                sql = "DELETE FROM cdr WHERE customer=:name"
                 db.query(sql, name=self.name)
             return None
         else:
@@ -129,7 +130,7 @@ class Customer(object):
                     result[date.strftime('%d%m%Y')].append(values)
                 with records.Database(url) as db:
                     sql = (
-                        "DELETE FROM cdr WHERE name=:name "
+                        "DELETE FROM cdr WHERE customer=:name "
                         "AND datetime>=:start AND datetime<=:stop"
                         )
                     db.query(
@@ -142,7 +143,7 @@ class Customer(object):
                 with records.Database(url) as db:
                     sql = (
                         "INSERT INTO cdr "
-                        "(name, datetime, source, octets_in, octets_out) "
+                        "(customer, datetime, source, octets_in, octets_out) "
                         "VALUES "
                         "(:name, :date_time, :source, :octetsin, :octetsout)"
                         )
@@ -173,7 +174,7 @@ class Customer(object):
         with records.Database(url) as db:
             sql = (
                 "SELECT * FROM cdr "
-                "WHERE name=:name "
+                "WHERE customer=:name "
                 "AND datetime >= :start "
                 "AND datetime <= :stop "
                 )
@@ -259,12 +260,16 @@ class Customer(object):
             result.append(info)
         return result
 
-    def apply_product_policies(self, for_real=False, from_db=True):
+    def apply_product_policies(self, for_real=False):
         """Application des politiques de bon usage du produit pour business"""
-        if not from_db:
-            cdrs = self.get_cdr_from_aiguillier()
-        else:
-            cdrs = self.get_cdr()
+        # on vérifie si le client a une configuration particulière
+        # pour la date à laquelle on doit commencer à compter
+        # sa consommation
+        key = 'cdr_start_date:{}'.format(self.name)
+        start = REDIS_DB.get(key)  # s'il n'y a pas de clés ce sera None
+        if start:
+            start = datetime.strptime(start + ' 00:00:00', '%d%m%Y %H:%M:%S')
+        cdrs = self.get_cdr(start=start)
         cdrs_by_policies = self.filter_cdrs_policy_wise(cdrs)
         for info in cdrs_by_policies:
             total = info['total']
