@@ -6,6 +6,7 @@ from functools import partial
 from multiprocessing.pool import Pool
 
 from .consts import CONFIG
+from .consts import LOGS
 from .consts import REST_CLIENT
 from . import core
 
@@ -96,14 +97,38 @@ class Product(object):
             params={'product': self.name}
             )
         customers = response['content'].get('customers', [])
-        if customers:
-            existing_customers_names = [
-                customer.name for customer in self.customers
-                ]
+        existing_customers_names = [
+            customer.name for customer in self.customers
+            ]
+        if not customers:
+            # on devrait supprimer tous les clients existants
+            # parce qu'Aiguillier nous dit que ce produit n'est
+            # lié à aucun client;
+            # mais pour des raisons de sécurité on ne touche à rien
+            pass
+        else:
+            deprecated_customers = filter(
+                lambda x: x not in [i['name'] for i in customers],
+                existing_customers_names
+                )  # il faut supprimer ces clients de la base
+            log_msg = (
+                "Les clients suivants seront supprimés de la base:\n{}".format(
+                    '\n'.join(deprecated_customers)
+                    )
+                )
+            LOGS.logger.info(log_msg)
+            # my_pool = Pool(4)
+            # my_pool.map(core.purge_customer, deprecated_customers)
             new_customers = filter(
                 lambda x: x['name'] not in existing_customers_names,
                 customers
+                )  # il faut ajouter ces clients dans la base
+            log_msg = (
+                "Les clients suivants seront ajoutés à la base:\n{}".format(
+                    '\n'.join(new_customers)
+                    )
                 )
+            LOGS.logger.info(log_msg)
             my_pool = Pool(4)
             my_pool.map(core.record_customer, new_customers)
 
